# PinnacleLink Python SDK 1.0.0

Welcome to the PinnacleLink SDK documentation. This guide will help you get started with integrating and using the PinnacleLink SDK in your project.

## Versions

- API version: `1.0.0`
- SDK version: `1.0.0`

## About the API

All about odds and fixtures # Authentication Please note that API has restriction that client password can be maximum up 10 characters long. API uses HTTP Basic access authentication. You need to send Authorization HTTP Request header: `Authorization: Basic ` Example: `Authorization: Basic U03MyOT23YbzMDc6d3c3O1DQ1`

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Environments](#environments)
  - [Setting an Environment](#setting-an-environment)
- [Services](#services)
- [Models](#models)

## Setup & Configuration

### Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

### Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install pinnacle-link-client
```

## Environments

The SDK supports different environments for various stages of development and deployment.

Here are the available environments:

```py
production = "https://api.pinnacle.com"
```

## Setting an Environment

To configure the SDK to use a specific environment, you can set the base URL as follows:

```py
from pinnacle_link import Environment

sdk.set_base_url(Environment.production.value)
```

## Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                         |
| :----------------------------------------------------------- |
| [FixturesService](documentation/services/FixturesService.md) |
| [OddsService](documentation/services/OddsService.md)         |
| [LineService](documentation/services/LineService.md)         |
| [OthersService](documentation/services/OthersService.md)     |

</details>
<br/>

## Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                                   | Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| :------------------------------------------------------------------------------------- | :  |
| [FixturesResponse](documentation/models/FixturesResponse.md)                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialsFixturesResponse](documentation/models/SpecialsFixturesResponse.md)           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SettledFixturesSport](documentation/models/SettledFixturesSport.md)                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SettledSpecialsResponse](documentation/models/SettledSpecialsResponse.md)             | Response dto for SettledSpecials request                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| [OddsResponse](documentation/models/OddsResponse.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsStraightV1GetOddsFormat](documentation/models/OddsStraightV1GetOddsFormat.md)     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserOddsResponse](documentation/models/TeaserOddsResponse.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialOddsResponse](documentation/models/SpecialOddsResponse.md)                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsSpecialV1GetOddsFormat](documentation/models/OddsSpecialV1GetOddsFormat.md)       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineResponse](documentation/models/LineResponse.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineStraightV1GetOddsFormat](documentation/models/LineStraightV1GetOddsFormat.md)     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineStraightV1GetBetType](documentation/models/LineStraightV1GetBetType.md)           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineStraightV1GetTeam](documentation/models/LineStraightV1GetTeam.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineStraightV1GetSide](documentation/models/LineStraightV1GetSide.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [ParlayLinesRequest](documentation/models/ParlayLinesRequest.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [ParlayLinesResponseV2](documentation/models/ParlayLinesResponseV2.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LinesRequestTeaser](documentation/models/LinesRequestTeaser.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserLinesResponse](documentation/models/TeaserLinesResponse.md)                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialLineResponse](documentation/models/SpecialLineResponse.md)                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineSpecialV1GetOddsFormat](documentation/models/LineSpecialV1GetOddsFormat.md)       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SportsResponse](documentation/models/SportsResponse.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [Leagues](documentation/models/Leagues.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SportPeriod](documentation/models/SportPeriod.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [InRunningResponse](documentation/models/InRunningResponse.md)                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserGroupsResponse](documentation/models/TeaserGroupsResponse.md)                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserGroupsV1GetOddsFormat](documentation/models/TeaserGroupsV1GetOddsFormat.md)     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [CancellationReasonResponse](documentation/models/CancellationReasonResponse.md)       | Cancellation Response Data                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| [SuccessfulCurrenciesResponse](documentation/models/SuccessfulCurrenciesResponse.md)   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [FixturesLeague](documentation/models/FixturesLeague.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [Fixture](documentation/models/Fixture.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [FixtureLiveStatus](documentation/models/FixtureLiveStatus.md)                         | Indicates live status of the event. <br><br>0 = No live betting will be offered on this event, <br>1 = Live betting event, <br>2 = Live betting will be offered on this match, but on a different event. Please note that [pre-game and live events are different](https://github.com/pinnacleapi/pinnacleapi-documentation/blob/master/FAQ.md#how-to-find-associated-events) .<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [FixtureStatus](documentation/models/FixtureStatus.md)                                 | This is deprecated parameter, please check period's `status` in the<br>`/odds` endpoint to see if it's open for betting.<br><br><br>O = This is the starting status of a game. <br><br>H = This status indicates that the lines are temporarily unavailable<br>for betting, <br><br>I = This status indicates that one or more lines have a red circle<br>(lower maximum bet amount).<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| [ParlayRestriction](documentation/models/ParlayRestriction.md)                         | <br>Parlay status of the event. <br><br>0 = Allowed to parlay, without restrictions, <br>1 = Not allowed to parlay this event, <br>2 = Allowed to parlay with the restrictions. You cannot have more than one leg from the same event in the parlay. All events with the same rotation number are treated as same event.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| [SpecialsFixturesLeague](documentation/models/SpecialsFixturesLeague.md)               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialFixture](documentation/models/SpecialFixture.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialFixtureBetType](documentation/models/SpecialFixtureBetType.md)                 | The type [MULTI_WAY_HEAD_TO_HEAD, SPREAD, OVER_UNDER]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| [SpecialFixtureStatus](documentation/models/SpecialFixtureStatus.md)                   | Status of the Special <br><br> O = This is the starting status. It means that the lines<br> are open for betting, <br><br> H = This status indicates that the lines are temporarily unavailable<br> for betting, <br><br> I = This status indicates that one or more lines have a red circle<br> (a lower maximum bet amount)<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [SpecialsFixturesEvent](documentation/models/SpecialsFixturesEvent.md)                 | Optional event asscoaited with the special.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [SpecialsFixturesContestant](documentation/models/SpecialsFixturesContestant.md)       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialFixtureLiveStatus](documentation/models/SpecialFixtureLiveStatus.md)           | When a special is linked to an event, we will return live status of the event, otherwise it will be 0. <br>0 = No live betting will be offered on this event, <br>1 = Live betting event, <br>2 = Live betting will be offered on this match, but on a different event. <br>Please note that live delay is applied when placing bets on special with LiveStatus=1 <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| [SettledFixturesLeague](documentation/models/SettledFixturesLeague.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SettledFixturesEvent](documentation/models/SettledFixturesEvent.md)                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SettledFixturesPeriod](documentation/models/SettledFixturesPeriod.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SettledFixturesPeriodStatus](documentation/models/SettledFixturesPeriodStatus.md)     | Period settlement status. <br><br>1 = Event period is settled, <br>2 = Event period is re-settled, <br>3 = Event period is cancelled, <br>4 = Event period is re-settled as cancelled, <br>5 = Event is deleted<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [CancellationReasonType](documentation/models/CancellationReasonType.md)               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [CancellationReasonDetailsType](documentation/models/CancellationReasonDetailsType.md) |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SettledSpecialsLeague](documentation/models/SettledSpecialsLeague.md)                 | League Dto to hold all settled specials for the league                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| [SettledSpecial](documentation/models/SettledSpecial.md)                               | Settled Special                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [CancellationReason](documentation/models/CancellationReason.md)                       | Cancellation Data                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [SettledContestants](documentation/models/SettledContestants.md)                       | Settled Special                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [Outcome](documentation/models/Outcome.md)                                             | Contestant outcomes<br>W = Won,<br>L = Lost, <br>X = Cancelled,<br>T = Tie,<br>Z = Scratched<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [OddsLeague](documentation/models/OddsLeague.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsEvent](documentation/models/OddsEvent.md)                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsPeriod](documentation/models/OddsPeriod.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsSpread](documentation/models/OddsSpread.md)                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsMoneyline](documentation/models/OddsMoneyline.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsTotal](documentation/models/OddsTotal.md)                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsTeamTotals](documentation/models/OddsTeamTotals.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [OddsTeamTotal](documentation/models/OddsTeamTotal.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserOddsLeague](documentation/models/TeaserOddsLeague.md)                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserOddsEvent](documentation/models/TeaserOddsEvent.md)                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserOddsPeriod](documentation/models/TeaserOddsPeriod.md)                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserOddsSpread](documentation/models/TeaserOddsSpread.md)                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserOddsTotalPoints](documentation/models/TeaserOddsTotalPoints.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialOddsLeague](documentation/models/SpecialOddsLeague.md)                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialOddsSpecial](documentation/models/SpecialOddsSpecial.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [SpecialOddsContestantLine](documentation/models/SpecialOddsContestantLine.md)         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LineResponseStatus](documentation/models/LineResponseStatus.md)                       | If the value is NOT_EXISTS, than this will be the only parameter in the response. All other params would be empty. [SUCCESS = OK, NOT_EXISTS = Line not offered anymore]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| [ParlayLinesRequestOddsFormat](documentation/models/ParlayLinesRequestOddsFormat.md)   | Odds in the response will be in this format. [American, Decimal, HongKong, Indonesian, Malay]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| [ParlayLineRequest](documentation/models/ParlayLineRequest.md)                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [LegBetType](documentation/models/LegBetType.md)                                       | SPREAD, MONEYLINE, TOTAL_POINTS and TEAM_TOTAL_POINTS are supported.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [ParlayLineRequestTeam](documentation/models/ParlayLineRequestTeam.md)                 | Chosen team type. This is needed only for SPREAD and MONEYLINE wager types. [Team1, Team2, Draw (MONEYLINE only)]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [ParlayLineRequestSide](documentation/models/ParlayLineRequestSide.md)                 | Chosen side. This is needed only for TOTAL_POINTS wager type. [OVER, UNDER]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [ParlayLinesResponseV2Status](documentation/models/ParlayLinesResponseV2Status.md)     | Status of the parlay [VALID = Parlay is valid, PROCESSED_WITH_ERROR = Parlay contains error(s)]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [RoundRobinOptionWithOddsV2](documentation/models/RoundRobinOptionWithOddsV2.md)       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [ParlayLineLeg](documentation/models/ParlayLineLeg.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [RoundRobinOption](documentation/models/RoundRobinOption.md)                           | RoundRobinOptions <br> <br> Parlay = Single parlay that include all wagers (No Round Robin), <br> TwoLegRoundRobin = Multiple parlays having 2 wagers each (round robin style), <br> ThreeLegRoundRobin = Multiple parlays having 3 wagers each (round robin style), <br> FourLegRoundRobin = Multiple parlays having 4 wagers each (round robin style), <br> FiveLegRoundRobin = Multiple parlays having 5 wagers each (round robin style), <br> SixLegRoundRobin = Multiple parlays having 6 wagers each (round robin style), <br> SevenLegRoundRobin = Multiple parlays having 7 wagers each (round robin style), <br> EightLegRoundRobin = Multiple parlays having 8 wagers each (round robin style) <br>                                                                                                                                            |
| [ParlayLineLegStatus](documentation/models/ParlayLineLegStatus.md)                     | Status of the request. [VALID = Valid leg, PROCESSED_WITH_ERROR = Processed with error]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| [ParlayLineLegErrorCode](documentation/models/ParlayLineLegErrorCode.md)               | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem. <br><br> CORRELATED - The leg is correlated with another one, <br> CANNOT_PARLAY_LIVE_GAME - The wager is placed on Live game, <br> EVENT_NO_LONGER_AVAILABLE_FOR_BETTING - The event is no longer offered for Parlays, <br> EVENT_NOT_OFFERED_FOR_PARLAY - The event is not offered for Parlays, <br> LINE_DOES_NOT_BELONG_TO_EVENT - LineId does not match the EventId specified in the request, <br> WAGER_TYPE_NO_LONGER_AVAILABLE_FOR_BETTING - Wager Type no longer available for betting, <br> WAGER_TYPE_NOT_VALID_FOR_PARLAY - Wager Type not valid for parlay, <br> WAGER_TYPE_CONFLICTS_WITH_OTHER_LEG - Wager Type conflicts with other leg<br> SAME_EVENT_PERIODS_ARE_DISALLOWED - It's not allowed to parlay selected periods of the same event.<br> |
| [LinesRequestTeaserOddsFormat](documentation/models/LinesRequestTeaserOddsFormat.md)   | Format the odds are returned in.. = [American, Decimal, HongKong, Indonesian, Malay]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [TeaserLineRequest](documentation/models/TeaserLineRequest.md)                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserLineRequestBetType](documentation/models/TeaserLineRequestBetType.md)           | Type of bet. Currently only SPREAD and TOTAL_POINTS are supported. [SPREAD, TOTAL_POINTS]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| [TeaserLineRequestTeam](documentation/models/TeaserLineRequestTeam.md)                 | Team being bet on for a spread line. [Team1, Team2]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [TeaserLineRequestSide](documentation/models/TeaserLineRequestSide.md)                 | Side of a total line being bet on. [OVER, UNDER]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [TeaserLinesResponseStatus](documentation/models/TeaserLinesResponseStatus.md)         | Status of the request. [VALID = Teaser is valid, PROCESSED_WITH_ERROR = Teaser contains one or more errors]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [TeaserLinesResponseErrorCode](documentation/models/TeaserLinesResponseErrorCode.md)   | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem. <br> <br> INVALID_LEGS = One or more of the legs is invalid,<br> SAME_EVENT_ONLY_REQUIRED = Teaser specified requires that all legs are from the same event, <br> TEASER_DISABLED = Teaser has been disabled and cannot be bet on, <br> TEASER_DOES_NOT_EXIST = The teaser identifier could not be found, <br> TOO_FEW_LEGS = You do not meet the minimum number of legs requirement for the teaser specified, <br> TOO_MANY_LEGS = You are above the maximum number of legs for the teaser specified, <br> UNKNOWN = An unknown error has occurred <br>                                                                                                                                                                                                           |
| [TeaserLineLeg](documentation/models/TeaserLineLeg.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserLineLegStatus](documentation/models/TeaserLineLegStatus.md)                     | Status of the request. [VALID = Teaser is valid, PROCESSED_WITH_ERROR = Teaser contains error(s)]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| [TeaserLineLegErrorCode](documentation/models/TeaserLineLegErrorCode.md)               | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem. <br> <br> EVENT_NOT_FOUND - The event specified could not be found, <br> POINTS_NO_LONGER_AVAILABLE - The points requested are no longer available. This means that the lines moved, <br> UNKNOWN - An unknown error has occured, <br> WAGER_TYPE_NOT_VALID_FOR_TEASER - The specified wager type is not valid for teasers <br> GAME_TEASER_DISABLED - Teasers are disabled for the event.<br>                                                                                                                                                                                                                                                                                                                                                                     |
| [SpecialLineResponseStatus](documentation/models/SpecialLineResponseStatus.md)         | Status [SUCCESS = OK, NOT_EXISTS = Line not offered anymore]                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| [Sport](documentation/models/Sport.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [League](documentation/models/League.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [InRunningSport](documentation/models/InRunningSport.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [InRunningLeague](documentation/models/InRunningLeague.md)                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [InRunningEvent](documentation/models/InRunningEvent.md)                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [State](documentation/models/State.md)                                                 | State of the game.<br><br>1 = First half in progress, <br>2 = Half time in progress, <br>3 = Second half in progress, <br>4 = End of regular time,<br>5 = First half extra time in progress, <br>6 = Extra time half time in progress, <br>7 = Second half extra time in progress, <br>8 = End of extra time, <br>9 = End of Game, <br>10 = Game is temporary suspended, <br>11 = Penalties in progress<br>                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [TeaserGroups](documentation/models/TeaserGroups.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserGroupsTeaser](documentation/models/TeaserGroupsTeaser.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserGroupsPayout](documentation/models/TeaserGroupsPayout.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserGroupsLeague](documentation/models/TeaserGroupsLeague.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [TeaserGroupsBetType](documentation/models/TeaserGroupsBetType.md)                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| [Currency](documentation/models/Currency.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |

</details>
<br/>
